=== modified file 'bin/lp-milestones'
--- old/bin/lp-milestones	2010-03-11 10:08:53 +0000
+++ new/bin/lp-milestones	2018-08-26 16:43:59 +0000
@@ -25,7 +25,7 @@
 import time
 
 # Might want to make errors import lazy.
-from bzrlib import errors
+from breezy import errors
 from launchpadlib.errors import HTTPError
 
 from lptools.command import *

=== modified file 'bin/lp-project'
--- old/bin/lp-project	2011-08-27 15:44:25 +0000
+++ new/bin/lp-project	2018-08-26 16:43:59 +0000
@@ -25,7 +25,7 @@
 import os
 
 # Might want to make errors import lazy.
-from bzrlib import bzrdir
+from breezy import controldir
 
 from lptools.command import *
 
@@ -55,7 +55,7 @@
     def run(self, project):
         self.outf.write('creating project %s\n' % project)
         # load the lp plugin - we needs it, but don't want its commands shown.
-        from bzrlib.plugins import launchpad
+        from breezy.plugins import launchpad
         project_d = {'project':project}
         mgmt = self.launchpad.people.newTeam(
             display_name='%s committers' % project, name=project,
@@ -96,7 +96,7 @@
         lp_host = os.environ.get('LAUNCHPAD_API', '')
         if lp_host:
             lp_host = '//%s/' % lp_host
-        branch = bzrdir.BzrDir.create_branch_convenience(
+        branch = controldir.ControlDir.create_branch_convenience(
             'lp:%s%s' % (lp_host, branch_path), force_new_tree=False)
         series = proj.getSeries(name='trunk')
         series.branch_link = self.launchpad.load(branch_path)

=== modified file 'lptools/command.py'
--- old/lptools/command.py	2010-03-11 10:19:10 +0000
+++ new/lptools/command.py	2018-08-26 16:43:59 +0000
@@ -38,7 +38,7 @@
 import os
 import sys
 
-from bzrlib import commands, ui, version_info as bzr_version_info
+from breezy import commands, ui, version_info as bzr_version_info
 
 from lptools import config
 
@@ -72,15 +72,15 @@
 class cmd_help(commands.Command):
     """Show help on a command or other topic."""
 
     # Can't use the stock bzrlib help, because the help indices aren't quite
     # generic enough.
     takes_args = ['topic?']
     def run(self, topic=None):
         if topic is None:
             self.outf.write(sys.modules['__main__'].__doc__)
         else:
-            import bzrlib.help
-            bzrlib.help.help(topic)
+            import breezy.help
+            breezy.help.help(topic)
 
 
 def do_run_bzr(argv):
@@ -72,15 +72,15 @@
     """Show help on a command or other topic."""
 
-    # Can't use the stock bzrlib help, because the help indices aren't quite
+    # Can't use the stock breezy help, because the help indices aren't quite
     # generic enough.
     takes_args = ['topic?']

